@@ -1,2 +1,5 @@
-__version__ = "0.3.3"
+from builder import build
+from analyser import analyze
+
+__version__ = "0.3.5"
 __author__ = [{"Henry Cook":"henryscookolaizola@gmail.com"}, {"Alejandro Sempere":"asempere@colegioaleman.net"}, "Pablo Pérez"]
\ No newline at end of file
