@@ -72,7 +72,7 @@ def nork(args):
     return verb
 
 
-def builder(args):
+def build(args):
     #If Aditza isn't None, raise an exception
     if args["Aditza"] != None:
         raise ValueError('Incorrect value for Aditza: Aditza always must have the value None. Read README.txt or the documentation at https://github.com/HCook86/Aditzak/blob/heroku/README.md for more information')
@@ -359,7 +359,10 @@ def builder(args):
             if args["Nor"] == "zu":
                 args["Aditza"] = "zait"
             if args["Nor"] == "zuek":
-                args["Aditza"] = "zait(zuek)"
+                if args["Modua"] == "Ahalera":
+                    args["Aditza"] = "zait"
+                else:    
+                    args["Aditza"] = "zait(zuek)"
             if args["Nor"] == "haiek":
                 args["Aditza"] = "dit"
         
@@ -385,7 +388,7 @@ def builder(args):
 
         if args["Modua"] == "Indikatiboa" or args["Modua"] == "Baldintza" or args["Modua"] == "Ondorioa":
             args["Aditza"] = args["Aditza"] + "u"
-        if args["Modua"] == "Subjuntiboa":
+        if args["Modua"] == "Subjuntiboa" or args["Modua"] == "Ahalera":
             args["Aditza"] = args["Aditza"] + "za"
 
         has_zte = ["Indikatiboa", "Baldintza", "Ahalera", "Baldintza", "Ondorioa"]
@@ -397,18 +400,36 @@ def builder(args):
         if args["Modua"] == "Ondorioa" and (args["Nor"] == "gu" or args["Nor"] == "zu"):
             args["Aditza"] = args["Aditza"] + "z"
 
-        if args["Modua"] == "Ondorioa":
+        if args["Modua"] == "Ondorioa" or args["Modua"] == "Ahalera":
             args["Aditza"] = args["Aditza"] + "ke"
 
+        if args["Modua"] == "Ahalera" and args["Nor"] == "zuek":
+            args["Aditza"] = args["Aditza"] + "te"
+
         args["Aditza"] = args["Aditza"] + "(nork)"
         args["Aditza"] = nork(args)
 
 
         if args["Modua"] == "Subjuntiboa" or args["Denbora"] == "Iragana":    
-            if args["Aditza"].endswith("u"):
+            if args["Aditza"].endswith("u") or args["Aditza"].endswith("e"):
                 args["Aditza"] = args["Aditza"] + "en"
             else: 
                 args["Aditza"] = args["Aditza"] + "n"
+        
+        if args["Modua"] == "Agintera":
+            if args["Denbora"] == "Iragana":
+                raise ValueError("Incorrect value for Denbora: Denbora only takes Oraina when Kasua is Agintera. Read README.txt or the documentation at https://github.com/HCook86/Aditzak/blob/heroku/README.md for more information")
+            else:
+                print("NOR-NORK AGINTERA")
+                if args["Nor"] == "ni":
+                    args["Aditza"] = "naza"
+                if args["Nor"] == "hura":
+                    args["Aditza"] = "beza"
+                if args["Nor"] == "gu":
+                    args["Aditza"] = "gaitza"    
+                if args["Nor"] == "haiek":
+                    args["Aditza"] = "bitza"
+
 
     elif args["Kasua"] == "NOR-NORI-NORK":
         print("NOR-NORI-NORK")
@@ -488,3 +509,5 @@ def builder(args):
     #If Kasua does not have a correct value
     else: raise ValueError('Incorrect value for Kasua. Read README.txt or the documentation at https://github.com/HCook86/Aditzak/blob/heroku/README.md for more information')
     return args["Aditza"]
+
+print(build({"Aditza":None, "Kasua":"NOR-NORK", "Modua":"Ahalera","Denbora":"Oraina", "Nor":"zuek", "Nori":None, "Nork":"hark"}))
\ No newline at end of file
